from __future__ import annotations

import typing

if typing.TYPE_CHECKING:
    StrOrInt: typing.TypeAlias = "str | int"
